@@ -54,199 +54,199 @@ static struct {
   const char *name;
   int token;
 } token_table[] = {
-  "over", OVER,
-  "smallover", SMALLOVER,
-  "sqrt", SQRT,
-  "sub", SUB,
-  "sup", SUP,
-  "lpile", LPILE,
-  "rpile", RPILE,
-  "cpile", CPILE,
-  "pile", PILE,
-  "left", LEFT,
-  "right", RIGHT,
-  "to", TO,
-  "from", FROM,
-  "size", SIZE,
-  "font", FONT,
-  "roman", ROMAN,
-  "bold", BOLD,
-  "italic", ITALIC,
-  "fat", FAT,
-  "bar", BAR,
-  "under", UNDER,
-  "accent", ACCENT,
-  "uaccent", UACCENT,
-  "above", ABOVE,
-  "fwd", FWD,
-  "back", BACK,
-  "down", DOWN,
-  "up", UP,
-  "matrix", MATRIX,
-  "col", COL,
-  "lcol", LCOL,
-  "rcol", RCOL,
-  "ccol", CCOL,
-  "mark", MARK,
-  "lineup", LINEUP,
-  "space", SPACE,
-  "gfont", GFONT,
-  "gsize", GSIZE,
-  "define", DEFINE,
-  "sdefine", SDEFINE,
-  "ndefine", NDEFINE,
-  "tdefine", TDEFINE,
-  "undef", UNDEF,
-  "ifdef", IFDEF,
-  "include", INCLUDE,
-  "copy", INCLUDE,
-  "delim", DELIM,
-  "chartype", CHARTYPE,
-  "type", TYPE,
-  "vcenter", VCENTER,
-  "set", SET,
-  "opprime", PRIME,
-  "grfont", GRFONT,
-  "gbfont", GBFONT,
-  "split", SPLIT,
-  "nosplit", NOSPLIT,
-  "special", SPECIAL,
+  { "over", OVER },
+  { "smallover", SMALLOVER },
+  { "sqrt", SQRT },
+  { "sub", SUB },
+  { "sup", SUP },
+  { "lpile", LPILE },
+  { "rpile", RPILE },
+  { "cpile", CPILE },
+  { "pile", PILE },
+  { "left", LEFT },
+  { "right", RIGHT },
+  { "to", TO },
+  { "from", FROM },
+  { "size", SIZE },
+  { "font", FONT },
+  { "roman", ROMAN },
+  { "bold", BOLD },
+  { "italic", ITALIC },
+  { "fat", FAT },
+  { "bar", BAR },
+  { "under", UNDER },
+  { "accent", ACCENT },
+  { "uaccent", UACCENT },
+  { "above", ABOVE },
+  { "fwd", FWD },
+  { "back", BACK },
+  { "down", DOWN },
+  { "up", UP },
+  { "matrix", MATRIX },
+  { "col", COL },
+  { "lcol", LCOL },
+  { "rcol", RCOL },
+  { "ccol", CCOL },
+  { "mark", MARK },
+  { "lineup", LINEUP },
+  { "space", SPACE },
+  { "gfont", GFONT },
+  { "gsize", GSIZE },
+  { "define", DEFINE },
+  { "sdefine", SDEFINE },
+  { "ndefine", NDEFINE },
+  { "tdefine", TDEFINE },
+  { "undef", UNDEF },
+  { "ifdef", IFDEF },
+  { "include", INCLUDE },
+  { "copy", INCLUDE },
+  { "delim", DELIM },
+  { "chartype", CHARTYPE },
+  { "type", TYPE },
+  { "vcenter", VCENTER },
+  { "set", SET },
+  { "opprime", PRIME },
+  { "grfont", GRFONT },
+  { "gbfont", GBFONT },
+  { "split", SPLIT },
+  { "nosplit", NOSPLIT },
+  { "special", SPECIAL },
 };
 
 static struct {
   const char *name;
   const char *def;
 } def_table[] = {
-  "ALPHA", "\\(*A",
-  "BETA", "\\(*B",
-  "CHI", "\\(*X",
-  "DELTA", "\\(*D",
-  "EPSILON", "\\(*E",
-  "ETA", "\\(*Y",
-  "GAMMA", "\\(*G",
-  "IOTA", "\\(*I",
-  "KAPPA", "\\(*K",
-  "LAMBDA", "\\(*L",
-  "MU", "\\(*M",
-  "NU", "\\(*N",
-  "OMEGA", "\\(*W",
-  "OMICRON", "\\(*O",
-  "PHI", "\\(*F",
-  "PI", "\\(*P",
-  "PSI", "\\(*Q",
-  "RHO", "\\(*R",
-  "SIGMA", "\\(*S",
-  "TAU", "\\(*T",
-  "THETA", "\\(*H",
-  "UPSILON", "\\(*U",
-  "XI", "\\(*C",
-  "ZETA", "\\(*Z",
-  "Alpha", "\\(*A",
-  "Beta", "\\(*B",
-  "Chi", "\\(*X",
-  "Delta", "\\(*D",
-  "Epsilon", "\\(*E",
-  "Eta", "\\(*Y",
-  "Gamma", "\\(*G",
-  "Iota", "\\(*I",
-  "Kappa", "\\(*K",
-  "Lambda", "\\(*L",
-  "Mu", "\\(*M",
-  "Nu", "\\(*N",
-  "Omega", "\\(*W",
-  "Omicron", "\\(*O",
-  "Phi", "\\(*F",
-  "Pi", "\\(*P",
-  "Psi", "\\(*Q",
-  "Rho", "\\(*R",
-  "Sigma", "\\(*S",
-  "Tau", "\\(*T",
-  "Theta", "\\(*H",
-  "Upsilon", "\\(*U",
-  "Xi", "\\(*C",
-  "Zeta", "\\(*Z",
-  "alpha", "\\(*a",
-  "beta", "\\(*b",
-  "chi", "\\(*x",
-  "delta", "\\(*d",
-  "epsilon", "\\(*e",
-  "eta", "\\(*y",
-  "gamma", "\\(*g",
-  "iota", "\\(*i",
-  "kappa", "\\(*k",
-  "lambda", "\\(*l",
-  "mu", "\\(*m",
-  "nu", "\\(*n",
-  "omega", "\\(*w",
-  "omicron", "\\(*o",
-  "phi", "\\(*f",
-  "pi", "\\(*p",
-  "psi", "\\(*q",
-  "rho", "\\(*r",
-  "sigma", "\\(*s",
-  "tau", "\\(*t",
-  "theta", "\\(*h",
-  "upsilon", "\\(*u",
-  "xi", "\\(*c",
-  "zeta", "\\(*z",
-  "max", "{type \"operator\" roman \"max\"}",
-  "min", "{type \"operator\" roman \"min\"}",
-  "lim", "{type \"operator\" roman \"lim\"}",
-  "sin", "{type \"operator\" roman \"sin\"}",
-  "cos", "{type \"operator\" roman \"cos\"}",
-  "tan", "{type \"operator\" roman \"tan\"}",
-  "sinh", "{type \"operator\" roman \"sinh\"}",
-  "cosh", "{type \"operator\" roman \"cosh\"}",
-  "tanh", "{type \"operator\" roman \"tanh\"}",
-  "arc", "{type \"operator\" roman \"arc\"}",
-  "log", "{type \"operator\" roman \"log\"}",
-  "ln", "{type \"operator\" roman \"ln\"}",
-  "exp", "{type \"operator\" roman \"exp\"}",
-  "Re", "{type \"operator\" roman \"Re\"}",
-  "Im", "{type \"operator\" roman \"Im\"}",
-  "det", "{type \"operator\" roman \"det\"}",
-  "and", "{roman \"and\"}",
-  "if", "{roman \"if\"}",
-  "for", "{roman \"for\"}",
-  "sum", "{type \"operator\" vcenter size +5 \\(*S}",
-  "prod", "{type \"operator\" vcenter size +5 \\(*P}",
-  "int", "{type \"operator\" vcenter size +8 \\(is}",
-  "union", "{type \"operator\" vcenter size +5 \\(cu}",
-  "inter", "{type \"operator\" vcenter size +5 \\(ca}",
-  "times", "type \"binary\" \\(mu",
-  "ldots", "type \"inner\" { . . . }",
-  "inf", "\\(if",
-  "partial", "\\(pd",
-  "nothing", "\"\"",
-  "half", "{1 smallover 2}",
-  "hat_def", "roman \"^\"",
-  "hat", "accent { hat_def }",
-  "dot_def", "back 15 \"\\v'-52M'.\\v'52M'\"",
-  "dot", "accent { dot_def }",
-  "dotdot_def", "back 25 \"\\v'-52M'..\\v'52M'\"",
-  "dotdot", "accent { dotdot_def }",
-  "tilde_def", "\"~\"",
-  "tilde", "accent { tilde_def }",
-  "utilde_def", "\"\\v'75M'~\\v'-75M'\"",
-  "utilde", "uaccent { utilde_def }",
-  "vec_def", "up 52 size -5 \\(->",
-  "vec", "accent { vec_def }",
-  "dyad_def", "up 52 size -5 {\\(<- back 60 \\(->}",
-  "dyad", "accent { dyad_def }",
-  "==", "type \"relation\" \\(==",
-  "!=", "type \"relation\" \\(!=",
-  "+-", "type \"binary\" \\(+-",
-  "->", "type \"relation\" \\(->",
-  "<-", "type \"relation\" \\(<-",
-  "<<", "{ < back 20 < }",
-  ">>", "{ > back 20 > }",
-  "...", "type \"inner\" vcenter { . . . }",
-  "prime", "'",
-  "approx", "type \"relation\" \"\\(~=\"",
-  "grad", "\\(gr",
-  "del", "\\(gr",
-  "cdot", "type \"binary\" vcenter .",
-  "dollar", "$",
+  { "ALPHA", "\\(*A" },
+  { "BETA", "\\(*B" },
+  { "CHI", "\\(*X" },
+  { "DELTA", "\\(*D" },
+  { "EPSILON", "\\(*E" },
+  { "ETA", "\\(*Y" },
+  { "GAMMA", "\\(*G" },
+  { "IOTA", "\\(*I" },
+  { "KAPPA", "\\(*K" },
+  { "LAMBDA", "\\(*L" },
+  { "MU", "\\(*M" },
+  { "NU", "\\(*N" },
+  { "OMEGA", "\\(*W" },
+  { "OMICRON", "\\(*O" },
+  { "PHI", "\\(*F" },
+  { "PI", "\\(*P" },
+  { "PSI", "\\(*Q" },
+  { "RHO", "\\(*R" },
+  { "SIGMA", "\\(*S" },
+  { "TAU", "\\(*T" },
+  { "THETA", "\\(*H" },
+  { "UPSILON", "\\(*U" },
+  { "XI", "\\(*C" },
+  { "ZETA", "\\(*Z" },
+  { "Alpha", "\\(*A" },
+  { "Beta", "\\(*B" },
+  { "Chi", "\\(*X" },
+  { "Delta", "\\(*D" },
+  { "Epsilon", "\\(*E" },
+  { "Eta", "\\(*Y" },
+  { "Gamma", "\\(*G" },
+  { "Iota", "\\(*I" },
+  { "Kappa", "\\(*K" },
+  { "Lambda", "\\(*L" },
+  { "Mu", "\\(*M" },
+  { "Nu", "\\(*N" },
+  { "Omega", "\\(*W" },
+  { "Omicron", "\\(*O" },
+  { "Phi", "\\(*F" },
+  { "Pi", "\\(*P" },
+  { "Psi", "\\(*Q" },
+  { "Rho", "\\(*R" },
+  { "Sigma", "\\(*S" },
+  { "Tau", "\\(*T" },
+  { "Theta", "\\(*H" },
+  { "Upsilon", "\\(*U" },
+  { "Xi", "\\(*C" },
+  { "Zeta", "\\(*Z" },
+  { "alpha", "\\(*a" },
+  { "beta", "\\(*b" },
+  { "chi", "\\(*x" },
+  { "delta", "\\(*d" },
+  { "epsilon", "\\(*e" },
+  { "eta", "\\(*y" },
+  { "gamma", "\\(*g" },
+  { "iota", "\\(*i" },
+  { "kappa", "\\(*k" },
+  { "lambda", "\\(*l" },
+  { "mu", "\\(*m" },
+  { "nu", "\\(*n" },
+  { "omega", "\\(*w" },
+  { "omicron", "\\(*o" },
+  { "phi", "\\(*f" },
+  { "pi", "\\(*p" },
+  { "psi", "\\(*q" },
+  { "rho", "\\(*r" },
+  { "sigma", "\\(*s" },
+  { "tau", "\\(*t" },
+  { "theta", "\\(*h" },
+  { "upsilon", "\\(*u" },
+  { "xi", "\\(*c" },
+  { "zeta", "\\(*z" },
+  { "max", "{type \"operator\" roman \"max\"}" },
+  { "min", "{type \"operator\" roman \"min\"}" },
+  { "lim", "{type \"operator\" roman \"lim\"}" },
+  { "sin", "{type \"operator\" roman \"sin\"}" },
+  { "cos", "{type \"operator\" roman \"cos\"}" },
+  { "tan", "{type \"operator\" roman \"tan\"}" },
+  { "sinh", "{type \"operator\" roman \"sinh\"}" },
+  { "cosh", "{type \"operator\" roman \"cosh\"}" },
+  { "tanh", "{type \"operator\" roman \"tanh\"}" },
+  { "arc", "{type \"operator\" roman \"arc\"}" },
+  { "log", "{type \"operator\" roman \"log\"}" },
+  { "ln", "{type \"operator\" roman \"ln\"}" },
+  { "exp", "{type \"operator\" roman \"exp\"}" },
+  { "Re", "{type \"operator\" roman \"Re\"}" },
+  { "Im", "{type \"operator\" roman \"Im\"}" },
+  { "det", "{type \"operator\" roman \"det\"}" },
+  { "and", "{roman \"and\"}" },
+  { "if", "{roman \"if\"}" },
+  { "for", "{roman \"for\"}" },
+  { "sum", "{type \"operator\" vcenter size +5 \\(*S}" },
+  { "prod", "{type \"operator\" vcenter size +5 \\(*P}" },
+  { "int", "{type \"operator\" vcenter size +8 \\(is}" },
+  { "union", "{type \"operator\" vcenter size +5 \\(cu}" },
+  { "inter", "{type \"operator\" vcenter size +5 \\(ca}" },
+  { "times", "type \"binary\" \\(mu" },
+  { "ldots", "type \"inner\" { . . . }" },
+  { "inf", "\\(if" },
+  { "partial", "\\(pd" },
+  { "nothing", "\"\"" },
+  { "half", "{1 smallover 2}" },
+  { "hat_def", "roman \"^\"" },
+  { "hat", "accent { hat_def }" },
+  { "dot_def", "back 15 \"\\v'-52M'.\\v'52M'\"" },
+  { "dot", "accent { dot_def }" },
+  { "dotdot_def", "back 25 \"\\v'-52M'..\\v'52M'\"" },
+  { "dotdot", "accent { dotdot_def }" },
+  { "tilde_def", "\"~\"" },
+  { "tilde", "accent { tilde_def }" },
+  { "utilde_def", "\"\\v'75M'~\\v'-75M'\"" },
+  { "utilde", "uaccent { utilde_def }" },
+  { "vec_def", "up 52 size -5 \\(->" },
+  { "vec", "accent { vec_def }" },
+  { "dyad_def", "up 52 size -5 {\\(<- back 60 \\(->}" },
+  { "dyad", "accent { dyad_def }" },
+  { "==", "type \"relation\" \\(==" },
+  { "!=", "type \"relation\" \\(!=" },
+  { "+-", "type \"binary\" \\(+-" },
+  { "->", "type \"relation\" \\(->" },
+  { "<-", "type \"relation\" \\(<-" },
+  { "<<", "{ < back 20 < }" },
+  { ">>", "{ > back 20 > }" },
+  { "...", "type \"inner\" vcenter { . . . }" },
+  { "prime", "'" },
+  { "approx", "type \"relation\" \"\\(~=\"" },
+  { "grad", "\\(gr" },
+  { "del", "\\(gr" },
+  { "cdot", "type \"binary\" vcenter ." },
+  { "dollar", "$" },
 };  
 
 void init_table(const char *device)
@@ -465,7 +465,7 @@ int top_input::get_location(char **fnp, int *lnp)
   return 1;
 }
 
-// Character respresenting $1.  Must be illegal input character.
+// Character representing $1.  Must be illegal input character.
 #define ARG1 14
 
 argument_macro_input::argument_macro_input(const char *body, int ac, 
