@@ -879,22 +879,22 @@ void resource_manager::process_file(int rank, FILE *fp, const char *filename,
   };
 
   static comment_info comment_table[] = {
-    "BeginResource:", &resource_manager::do_begin_resource,
-    "IncludeResource:", &resource_manager::do_include_resource,
-    "BeginDocument:", &resource_manager::do_begin_document,
-    "IncludeDocument:", &resource_manager::do_include_document,
-    "BeginProcSet:", &resource_manager::do_begin_procset,
-    "IncludeProcSet:", &resource_manager::do_include_procset,
-    "BeginFont:", &resource_manager::do_begin_font,
-    "IncludeFont:", &resource_manager::do_include_font,
-    "BeginFile:", &resource_manager::do_begin_file,
-    "IncludeFile:", &resource_manager::do_include_file,
-    "EndProcSet", &resource_manager::change_to_end_resource,
-    "EndFont", &resource_manager::change_to_end_resource,
-    "EndFile", &resource_manager::change_to_end_resource,
-    "BeginPreview:", &resource_manager::do_begin_preview,
-    "BeginData:", &resource_manager::do_begin_data,
-    "BeginBinary:", &resource_manager::do_begin_binary,
+    { "BeginResource:", &resource_manager::do_begin_resource },
+    { "IncludeResource:", &resource_manager::do_include_resource },
+    { "BeginDocument:", &resource_manager::do_begin_document },
+    { "IncludeDocument:", &resource_manager::do_include_document },
+    { "BeginProcSet:", &resource_manager::do_begin_procset },
+    { "IncludeProcSet:", &resource_manager::do_include_procset },
+    { "BeginFont:", &resource_manager::do_begin_font },
+    { "IncludeFont:", &resource_manager::do_include_font },
+    { "BeginFile:", &resource_manager::do_begin_file },
+    { "IncludeFile:", &resource_manager::do_include_file },
+    { "EndProcSet", &resource_manager::change_to_end_resource },
+    { "EndFont", &resource_manager::change_to_end_resource },
+    { "EndFile", &resource_manager::change_to_end_resource },
+    { "BeginPreview:", &resource_manager::do_begin_preview },
+    { "BeginData:", &resource_manager::do_begin_data },
+    { "BeginBinary:", &resource_manager::do_begin_binary },
   };
   
   const int NCOMMENTS = sizeof(comment_table)/sizeof(comment_table[0]);
