@@ -39,7 +39,7 @@ static void usage()
   exit(1);
 }
 
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
   program_name = argv[0];
   static char stderr_buf[BUFSIZ];
@@ -118,5 +118,5 @@ main(int argc, char **argv)
       putchar('\n');
     putchar('\n');
   }
-  exit(!count);
+  return !count;
 }
