@@ -636,52 +636,52 @@ struct {
   command_t func;
   const char *arg_types;
 } command_table[] = {
-  "include", include_command, "s",
-  "echo", echo_command, "s*",
-  "capitalize", capitalize_command, "f?",
-  "accumulate", accumulate_command, "",
-  "no-accumulate", no_accumulate_command, "",
-  "move-punctuation", move_punctuation_command, "",
-  "no-move-punctuation", no_move_punctuation_command, "",
-  "sort", sort_command, "s?",
-  "no-sort", no_sort_command, "",
-  "articles", articles_command, "s*",
-  "database", database_command, "ss*",
-  "default-database", default_database_command, "",
-  "no-default-database", no_default_database_command, "",
-  "bibliography", bibliography_command, "ss*",
-  "annotate", annotate_command, "F?s?",
-  "no-annotate", no_annotate_command, "",
-  "reverse", reverse_command, "s",
-  "no-reverse", no_reverse_command, "",
-  "abbreviate", abbreviate_command, "ss?s?s?s?",
-  "no-abbreviate", no_abbreviate_command, "",
-  "search-ignore", search_ignore_command, "f?",
-  "no-search-ignore", no_search_ignore_command, "",
-  "search-truncate", search_truncate_command, "i?",
-  "no-search-truncate", no_search_truncate_command, "",
-  "discard", discard_command, "f?",
-  "no-discard", no_discard_command, "",
-  "label", label_command, "s",
-  "abbreviate-label-ranges", abbreviate_label_ranges_command, "s?",
-  "no-abbreviate-label-ranges", no_abbreviate_label_ranges_command, "",
-  "label-in-reference", label_in_reference_command, "",
-  "no-label-in-reference", no_label_in_reference_command, "",
-  "label-in-text", label_in_text_command, "",
-  "no-label-in-text", no_label_in_text_command, "",
-  "sort-adjacent-labels", sort_adjacent_labels_command, "",
-  "no-sort-adjacent-labels", no_sort_adjacent_labels_command, "",
-  "date-as-label", date_as_label_command, "s?",
-  "no-date-as-label", no_date_as_label_command, "",
-  "short-label", short_label_command, "s",
-  "no-short-label", no_short_label_command, "",
-  "compatible", compatible_command, "",
-  "no-compatible", no_compatible_command, "",
-  "join-authors", join_authors_command, "sss?",
-  "bracket-label", bracket_label_command, "sss",
-  "separate-label-second-parts", separate_label_second_parts_command, "s",
-  "et-al", et_al_command, "sii?",
-  "no-et-al", no_et_al_command, "",
+  { "include", include_command, "s" },
+  { "echo", echo_command, "s*" },
+  { "capitalize", capitalize_command, "f?" },
+  { "accumulate", accumulate_command, "" },
+  { "no-accumulate", no_accumulate_command, "" },
+  { "move-punctuation", move_punctuation_command, "" },
+  { "no-move-punctuation", no_move_punctuation_command, "" },
+  { "sort", sort_command, "s?" },
+  { "no-sort", no_sort_command, "" },
+  { "articles", articles_command, "s*" },
+  { "database", database_command, "ss*" },
+  { "default-database", default_database_command, "" },
+  { "no-default-database", no_default_database_command, "" },
+  { "bibliography", bibliography_command, "ss*" },
+  { "annotate", annotate_command, "F?s?" },
+  { "no-annotate", no_annotate_command, "" },
+  { "reverse", reverse_command, "s" },
+  { "no-reverse", no_reverse_command, "" },
+  { "abbreviate", abbreviate_command, "ss?s?s?s?" },
+  { "no-abbreviate", no_abbreviate_command, "" },
+  { "search-ignore", search_ignore_command, "f?" },
+  { "no-search-ignore", no_search_ignore_command, "" },
+  { "search-truncate", search_truncate_command, "i?" },
+  { "no-search-truncate", no_search_truncate_command, "" },
+  { "discard", discard_command, "f?" },
+  { "no-discard", no_discard_command, "" },
+  { "label", label_command, "s" },
+  { "abbreviate-label-ranges", abbreviate_label_ranges_command, "s?" },
+  { "no-abbreviate-label-ranges", no_abbreviate_label_ranges_command, "" },
+  { "label-in-reference", label_in_reference_command, "" },
+  { "no-label-in-reference", no_label_in_reference_command, "" },
+  { "label-in-text", label_in_text_command, "" },
+  { "no-label-in-text", no_label_in_text_command, "" },
+  { "sort-adjacent-labels", sort_adjacent_labels_command, "" },
+  { "no-sort-adjacent-labels", no_sort_adjacent_labels_command, "" },
+  { "date-as-label", date_as_label_command, "s?" },
+  { "no-date-as-label", no_date_as_label_command, "" },
+  { "short-label", short_label_command, "s" },
+  { "no-short-label", no_short_label_command, "" },
+  { "compatible", compatible_command, "" },
+  { "no-compatible", no_compatible_command, "" },
+  { "join-authors", join_authors_command, "sss?" },
+  { "bracket-label", bracket_label_command, "sss" },
+  { "separate-label-second-parts", separate_label_second_parts_command, "s" },
+  { "et-al", et_al_command, "sii?" },
+  { "no-et-al", no_et_al_command, "" },
 };
 
 static int check_args(const char *types, const char *name,
